netapp_ontap.models.datacollection_version_data_collection_embedding API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.datacollection_version_data_collection_embedding`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class DatacollectionVersionDataCollectionEmbeddingSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the DatacollectionVersionDataCollectionEmbedding object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `chunk_size: Size GET POST PATCH`

    The chunk size value in the range (3..1536)

    Example: 1536

  `chunk_type: str GET POST PATCH`

    The type of chunking.

    Valid choices:

    - sentence
    - paragraph
    - full_file
    - semantic
    - recursive
    - fixed_size
  `dimension: Size GET POST PATCH`

    The dimension of vectorization.

    Example: 1024

  `enabled: bool GET POST PATCH`

    Indicates whether vectorization is enabled.

    Example: true

  `quantization: str GET POST PATCH`

    The vector quantization value.

    Valid choices:

    - fp32
    - fp16
    - fp8
    - uint8
  `re_rank: bool GET POST PATCH`

    Indicates whether re_rank is enabled

    Example: true